Formal Power Series
===================

Methods for computing and manipulating Formal Power Series.

.. autoclass:: sympy.series.formal::FormalPowerSeries
   :members:

.. autofunction:: sympy.series.formal::fps

.. autofunction:: sympy.series.formal::compute_fps

.. autoclass:: sympy.series.formal::FormalPowerSeriesCompose
   :members:

.. autoclass:: sympy.series.formal::FormalPowerSeriesInverse
   :members:

.. autoclass:: sympy.series.formal::FormalPowerSeriesProduct
   :members:

.. autoclass:: sympy.series.formal::FiniteFormalPowerSeries
   :members:


Rational Algorithm
------------------

.. autofunction:: sympy.series.formal::rational_independent

.. autofunction:: sympy.series.formal::rational_algorithm

Hypergeometric Algorithm
------------------------

.. autofunction:: sympy.series.formal::simpleDE

.. autofunction:: sympy.series.formal::exp_re

.. autofunction:: sympy.series.formal::hyper_re

.. autofunction:: sympy.series.formal::rsolve_hypergeometric

.. autofunction:: sympy.series.formal::solve_de

.. autofunction:: sympy.series.formal::hyper_algorithm
